@@ -5,6 +5,7 @@ use warnings;
 
 use Getopt::Long;
 use Chart::GGPlot qw(:all);
+use Chart::GGPlot::Trans::Functions qw(reciprocal_trans);
 use Data::Frame::Examples qw(mpg);
 
 my $save_as;
@@ -16,7 +17,7 @@ my $p = ggplot(
     data    => $mpg,
     mapping => aes( x => 'displ', y => 'hwy' )
 )->geom_point()
- ->scale_x_continuous(limits => [2, 6]);
+ ->scale_y_continuous(trans => reciprocal_trans());
 
 if ( defined $save_as ) {
     $p->save($save_as);
